@@ -2,6 +2,6 @@ from easyprocess import EasyProcess
 from pyvirtualdisplay.smartdisplay import SmartDisplay
 
 disp = SmartDisplay(visible=0, bgcolor='black')
-func = disp.wrap(EasyProcess('xmessage screenshot').wrap(disp.waitgrab))
+func = disp.wrap(EasyProcess('xmessage hello').wrap(disp.waitgrab))
 img=func()
 img.show()
